#!/usr/bin/env node

/**
 * This small tool takes an introspection schema JSON and
 * converts it into the GraphQL Schema Definition Language.
 */

const fs = require('fs');
const program = require('commander');
const { printSchema, buildClientSchema } = require('graphql');

program.version('1.0.2');
program
  .option(
    '-i, --inputFile <file>',
    'File path and name of the schema JSON (e.g. schema.json or src/graphql/schema.json)',
  )
  .option(
    '-o, --outputFile <file>',
    'File path and name where the schema GRAPHQL should be stored (e.g. schema.graphql or src/graphql/schema.graphql)',
  );

program.parse(process.argv);

if (!program.inputFile || !program.outputFile) {
  throw new Error('Input and Output must be defined! See --help for details.');
}

const schema = require(process.cwd() + '/' + program.inputFile); // eslint-disable-line

const clientSchema = buildClientSchema(schema);

const graphqls = printSchema(clientSchema);

fs.writeFile(process.cwd() + '/' + program.outputFile, graphqls, function(err) {
  if (err) {
    return console.log(err);
  }

  console.log('success transforming' + program.inputFile + ' into ' + program.outputFile);
});
